Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(114)

Unified Diff: chrome/browser/chromeos/settings/shutdown_policy_handler.h

Issue 811033002: Add device policy to disallow shutdown - ash UI modifications (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: reduced scope of CL (ash only now, removed webui changes) Created 5 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/settings/shutdown_policy_handler.h
diff --git a/chrome/browser/ui/webui/chromeos/login/shutdown_policy_observer.h b/chrome/browser/chromeos/settings/shutdown_policy_handler.h
similarity index 74%
rename from chrome/browser/ui/webui/chromeos/login/shutdown_policy_observer.h
rename to chrome/browser/chromeos/settings/shutdown_policy_handler.h
index c7a0881dfd49f242c53674eb7b3fef88241ad942..2104b9aa1f605cbf9a66f12c840e327f8c062d9b 100644
--- a/chrome/browser/ui/webui/chromeos/login/shutdown_policy_observer.h
+++ b/chrome/browser/chromeos/settings/shutdown_policy_handler.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_WEBUI_CHROMEOS_LOGIN_SHUTDOWN_POLICY_OBSERVER_H_
-#define CHROME_BROWSER_UI_WEBUI_CHROMEOS_LOGIN_SHUTDOWN_POLICY_OBSERVER_H_
+#ifndef CHROME_BROWSER_CHROMEOS_SETTINGS_SHUTDOWN_POLICY_HANDLER_H_
+#define CHROME_BROWSER_CHROMEOS_SETTINGS_SHUTDOWN_POLICY_HANDLER_H_
#include "base/callback_forward.h"
#include "base/macros.h"
@@ -14,9 +14,9 @@
namespace chromeos {
// This class observes the device setting |DeviceRebootOnShutdown|. Changes to
// this policy are communicated to the ShutdownPolicyObserver::Delegate by
// calling its OnShutdownPolicyChanged method with the new state of the policy.
-class ShutdownPolicyObserver {
+class ShutdownPolicyHandler {
public:
// This callback is passed to CheckIfRebootOnShutdown, which invokes it with
// the current state of the |DeviceRebootOnShutdown| policy once a trusted of
@@ -32,8 +32,8 @@ class ShutdownPolicyObserver {
virtual ~Delegate() {}
};
- ShutdownPolicyObserver(CrosSettings* cros_settings, Delegate* delegate);
- ~ShutdownPolicyObserver();
+ ShutdownPolicyHandler(CrosSettings* cros_settings, Delegate* delegate);
+ ~ShutdownPolicyHandler();
// Once a trusted set of policies is established, this function calls
// |callback| with the trusted state of the |DeviceRebootOnShutdown| policy.
@@ -53,11 +53,11 @@ class ShutdownPolicyObserver {
scoped_ptr<CrosSettings::ObserverSubscription> shutdown_policy_subscription_;
- base::WeakPtrFactory<ShutdownPolicyObserver> weak_factory_;
+ base::WeakPtrFactory<ShutdownPolicyHandler> weak_factory_;
- DISALLOW_COPY_AND_ASSIGN(ShutdownPolicyObserver);
+ DISALLOW_COPY_AND_ASSIGN(ShutdownPolicyHandler);
};
} // namespace chromeos
-#endif // CHROME_BROWSER_UI_WEBUI_CHROMEOS_LOGIN_SHUTDOWN_POLICY_OBSERVER_H_
+#endif // CHROME_BROWSER_CHROMEOS_SETTINGS_SHUTDOWN_POLICY_HANDLER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -14,9 +14,9 @@
namespace chromeos {
// This class observes the device setting |DeviceRebootOnShutdown|. Changes to
-// this policy are communicated to the ShutdownPolicyObserver::Delegate by
+// this policy are communicated to the ShutdownPolicyHandler::Delegate by
// calling its OnShutdownPolicyChanged method with the new state of the policy.